# ChatGPT API Key

LetMeDoIt AI utilizes OpenAI API key, so to use LetMeDoItAI, you have to get a OpenAI API key.

# How to Obtain?

To obtain an OpenAI API key, you can follow these steps:

1. Visit OpenAI’s official site via your preferred browser.

> https://platform.openai.com/account/api-keys

2. Tap on “Log-In” and add your email.

3. Click on the “View API Keys” icon in the top-right area of your screen.

4. Select the “Create an API Key” icon to set your API Key.

[After this, your API Key will be generated]

# Pricing

Charges are applied based on usage:

Read pricing at https://openai.com/pricing

# Enter your OpenAI API Key for the First Launch

<img width="857" alt="EnterOpenAI_API_key" src="https://github.com/eliranwong/letmedoit/assets/25262722/5e57ee82-49eb-4ea2-a7f0-87df542fc5a0">
